%
% An idealized maize root system in a pot using parameters from literature 
% with 10% standard deviation.
%
% Copyright 2008-2014 Daniel Leitner. See license.txt for details.
%

clear all;
set(0,'RecursionLimit',10000);

% Tap root 
p{1}.name = 'tap root';
p{1}.r = [2,0.2];
p{1}.lb = [0.7,0.07];          
p{1}.la = [15.7,1.57];                    
p{1}.ln = [0.7,0.07];                 
p{1}.nob = [50,5];  
p{1}.a = 0.03;   
p{1}.theta = 0;
p{1}.color = [55/255,50/255,25/255];
p{1}.tropism = [1,2,15*pi/180]; 
p{1}.dx= 0.25; 
p{1}.successor = [2,1];

% 1st order lateral
p{2}.name = '1st order lateral';
p{2}.r = [6.4, 0.64];
p{2}.lb = [0.7, 0.07];    
p{2}.la = [2.7, 0.27];                       
p{2}.ln = [0.7, 0.07];               
p{2}.nob = [7, 0.7];                  
p{2}.a = 0.02;                
p{2}.theta = [63*pi/180,0];      
p{2}.color = [140/255,125/255,40/255];
p{2}.tropism = [1,0.5,40*pi/180]; 
p{2}.dx= 0.25;
% p{2}.successor = [3,1];
% 
% % 2nd order lateral
% p{3}.name = '2nd order lateral';
% p{3}.r  = [1.5,0.15];                                        
% p{3}.la  = [0.2,0.02];                    
% p{3}.a  = 0.01;                                 
% p{3}.theta = [68*pi/180,3*pi/180];        
% p{3}.color = [160/255,150/255,30/255];
% p{3}.tropism = [1,0,40*pi/180];
% p{3}.dx= 0.25;

% plant pot geometry 
r1=7;
r2=4;
h=15;
pot = @(p) distPot(p,r1,r2,h);

%p = completeParameters(p,pot);
p = completeParameters(p);

% Simulate
n0=7; % tap roots
r0=5; % cm
simtime = 15;% days
root = createRootSystem(0,0,2*rand(n0,1),zeros(7,1),r0); 
tic 
str = applyRules(root,simtime); % takes some time...
toc    

% plot root system
plotTubes(str);
X = linspace(-r1,r1,100); 
Y = linspace(-r1,r1,100);
Z = linspace(-h,0,40);
%plotDistFunc(pot,X,Y,Z,[0 0 1]); % approximate the pot boundaries
view(3);

% % Movie 
% mtime = 10; % seconds
% simtime = 40; % days
% fview = @(frame) view(3);
% makeMovie('Maize.avi',root,simtime,mtime,fview); 
