function [m,epl,al] = fitFitter(A)
% fitFitter: topolgy parameters from Fitter, AH (1987).
%
% A             adjacency matrix
%
% m             magnitude: number of exterior links (number of root tips)
% ep            external path length: sum of the number of links in all
%               paths from all external links to the base link 
% al            altitude: number of links in the longest path from any 
%               exterior link to the origin 
%
% See also: getGraph2
%
% Copyright 2008-2014 Daniel Leitner. See license.txt for details.
%

A_ = zeros(size(A,1),1);

for i = 1 : length(A)
    A_(i) = graphshortestpath(A>0,1,i);
end

l=[]; % find leaf indices (external links)
for k = 1 : size(A,1)
    if isempty(find(A(k,:),1))
        l = [l,k];
    end
end

m = length(l); % magnitude
epl = sum(A_(l)); % external path length
al = max(A_(l)); % altitude


% function n = labelMagnitude(i,S)
% 
% if S(i,:)==0
%     n=1;
% else
%     ind = find(S(i,:));
%     z=0;
%     for j = 1 : length(ind)
%         z = z + labelMagnitude(ind(j),S);
%     end
%     n=z;
% end


